import EventDispatcher from "../../../event-system/cocos-event-target";
import { SETTING_EVENT } from "../event-setting-config";
import { SettingToggleButton } from "./setting-toggle-button";

const { ccclass, property } = cc._decorator;

@ccclass
export default class SettingComponent extends cc.Component
{
    private isShow: boolean = false;

    @property(cc.Node)
    private nodeContainer: cc.Node = null;
    @property(SettingToggleButton)
    private toggleButtonSfx: SettingToggleButton = null;
    @property(SettingToggleButton)
    private toggleButtonMusic: SettingToggleButton = null;
    @property(SettingToggleButton)
    private toggleButtonExpand: SettingToggleButton = null;

    protected onLoad(): void
    {
        this.hide();
    }

    private show(): void
    {
        this.isShow = true;
        this.nodeContainer.active = true;
    }

    private hide(): void
    {
        this.isShow = false;
        this.nodeContainer.active = false;
    }

    private onClickSettingButton(): void
    {
        if (this.isShow)
        {
            this.hide();
        } else
        {
            this.show();
        }
    }

    private onClickInfoButton(): void
    {
        EventDispatcher.emit(SETTING_EVENT.OnClickInfoButton);
        this.hide();
    }

    private onClickHistoryButton(): void
    {
        EventDispatcher.emit(SETTING_EVENT.OnClickHistoryButton);
        this.hide();
    }

    private onClickSfxButton(): void
    {
        this.toggleButtonSfx.onClickToggleButton();
        EventDispatcher.emit(SETTING_EVENT.OnClickSFXButton, this.toggleButtonSfx.isOn);
    }

    private onClickMusicButton(): void
    {
        this.toggleButtonMusic.onClickToggleButton();
        EventDispatcher.emit(SETTING_EVENT.OnClickMusicButton, this.toggleButtonMusic.isOn);
    }

    private onClickExpandButton(): void
    {
        this.toggleButtonExpand.onClickToggleButton();
        EventDispatcher.emit(SETTING_EVENT.OnClickExpandButton, this.toggleButtonExpand.isOn);
    }

    private onClickHomeButton(): void
    {
        EventDispatcher.emit(SETTING_EVENT.OnClickHomeButton);
        this.hide();
    }
}
